@@ -20,10 +20,9 @@ use solana_measure::measure::Measure;
 use solana_metrics::{inc_new_counter_error, inc_new_counter_info};
 use solana_poh::poh_recorder::WorkingBankEntry;
 use solana_runtime::bank::Bank;
-use solana_sdk::timing::timestamp;
+use solana_sdk::timing::{timestamp, AtomicInterval};
 use solana_sdk::{clock::Slot, pubkey::Pubkey};
 use solana_streamer::{sendmmsg::send_mmsg, socket::SocketAddrSpace};
-use std::sync::atomic::AtomicU64;
 use std::{
     collections::HashMap,
     net::UdpSocket,
@@ -362,14 +361,9 @@ impl BroadcastStage {
 fn update_peer_stats(
     num_live_peers: i64,
     broadcast_len: i64,
-    last_datapoint_submit: &Arc<AtomicU64>,
+    last_datapoint_submit: &Arc<AtomicInterval>,
 ) {
-    let now = timestamp();
-    let last = last_datapoint_submit.load(Ordering::Relaxed);
-    #[allow(deprecated)]
-    if now.saturating_sub(last) > 1000
-        && last_datapoint_submit.compare_and_swap(last, now, Ordering::Relaxed) == last
-    {
+    if last_datapoint_submit.should_update(1000) {
         datapoint_info!(
             "cluster_info-num_nodes",
             ("live_count", num_live_peers, i64),
@@ -384,7 +378,7 @@ pub fn broadcast_shreds(
     s: &UdpSocket,
     shreds: &[Shred],
     cluster_nodes: &ClusterNodes<BroadcastStage>,
-    last_datapoint_submit: &Arc<AtomicU64>,
+    last_datapoint_submit: &Arc<AtomicInterval>,
     transmit_stats: &mut TransmitShredsStats,
     socket_addr_space: &SocketAddrSpace,
 ) -> Result<()> {
