@@ -149,13 +149,6 @@ impl RepairPeers {
 }
 
 impl ServeRepair {
-    /// Without a valid keypair gossip will not function. Only useful for tests.
-    pub fn new_with_invalid_keypair(contact_info: ContactInfo) -> Self {
-        Self::new(Arc::new(ClusterInfo::new_with_invalid_keypair(
-            contact_info,
-        )))
-    }
-
     pub fn new(cluster_info: Arc<ClusterInfo>) -> Self {
         let (keypair, my_info) = { (cluster_info.keypair.clone(), cluster_info.my_contact_info()) };
         Self {
@@ -652,7 +645,8 @@ mod tests {
         shred::{max_ticks_per_n_shreds, Shred},
     };
     use solana_perf::packet::Packet;
-    use solana_sdk::{hash::Hash, pubkey::Pubkey, timing::timestamp};
+    use solana_sdk::{hash::Hash, pubkey::Pubkey, signature::Keypair, timing::timestamp};
+    use solana_streamer::socket::SocketAddrSpace;
 
     #[test]
     fn test_run_highest_window_request() {
@@ -797,11 +791,19 @@ mod tests {
         Blockstore::destroy(&ledger_path).expect("Expected successful database destruction");
     }
 
+    fn new_test_cluster_info(contact_info: ContactInfo) -> ClusterInfo {
+        ClusterInfo::new(
+            contact_info,
+            Arc::new(Keypair::new()),
+            SocketAddrSpace::Unspecified,
+        )
+    }
+
     #[test]
     fn window_index_request() {
         let cluster_slots = ClusterSlots::default();
         let me = ContactInfo::new_localhost(&solana_sdk::pubkey::new_rand(), timestamp());
-        let cluster_info = Arc::new(ClusterInfo::new_with_invalid_keypair(me));
+        let cluster_info = Arc::new(new_test_cluster_info(me));
         let serve_repair = ServeRepair::new(cluster_info.clone());
         let mut outstanding_requests = OutstandingRepairs::default();
         let rv = serve_repair.repair_request(
@@ -1028,7 +1030,7 @@ mod tests {
     fn test_repair_with_repair_validators() {
         let cluster_slots = ClusterSlots::default();
         let me = ContactInfo::new_localhost(&solana_sdk::pubkey::new_rand(), timestamp());
-        let cluster_info = Arc::new(ClusterInfo::new_with_invalid_keypair(me.clone()));
+        let cluster_info = Arc::new(new_test_cluster_info(me.clone()));
 
         // Insert two peers on the network
         let contact_info2 =
